#!/bin/bash

test -f scripts/ggrelay || exit 1
test -f scripts/ggrelay.conf || exit 1
test -f autogen.sh  || exit 1

fail()
{
	echo "installation failed: $*"
	exit 1
}

noconf()
{
	echo "Please create /etc/ggrelay/ggrelay.conf manually to make scripts work."
	exit 0;
}

RPMBUILDDIR=
[ "$1" == "--rpmbuild" ] && RPMBUILDDIR="$2"

if [ -z "$RPMBUILDDIR" ]; then
	echo "Building ..."
	test -f configure || ./autogen.sh || fail "autogen.sh failed"
	./configure --enable-debug || fail "configure failed"
	make || fail "make failed"
	make install || fail "make install failed"
fi

echo "Installing scripts ..."
install -d $RPMBUILDDIR/etc/rc.d/init.d
install scripts/ggrelay $RPMBUILDDIR/etc/rc.d/init.d/ || fail "error copying to /etc/rc.d/init.d"
[ -z "$RPMBUILDDIR" ] && /sbin/chkconfig --add ggrelay

if ! test "$1" = "--noconf"; then
	install -d $RPMBUILDDIR/etc/ggrelay
	if test -f $RPMBUILDDIR/etc/ggrelay.conf; then
		echo "note: /etc/ggrelay.conf is deprecated. New config will be generated"
		echo "      as /etc/ggrelay/ggrelay.conf"
		echo
	fi
	if ! test -f $RPMBUILDDIR/etc/ggrelay/ggrelay.conf; then
		echo "To create /etc/ggrelay/ggrelay.conf I need some info from you."
		if [ -n "$RPMBUILDDIR" ]; then
			sed "s/<EXTIF>//;s/<INTIF>//" scripts/ggrelay.conf \
				> $RPMBUILDDIR/etc/ggrelay/ggrelay.conf
		else
			read -p "Your external interface: " EXTIF
			test -z "$EXTIF" && noconf
			read -p "Your internal interface: " INTIF
			test -z "$INTIF" && noconf
			sed "s/<EXTIF>/-o $EXTIF/;s/<INTIF>/-i $INTIF/" scripts/ggrelay.conf \
				> /etc/ggrelay/ggrelay.conf
		fi
		echo
		echo "Generated ggrelay.conf:"
		echo "--- CUT HERE ---"
		cat $RPMBUILDDIR/etc/ggrelay/ggrelay.conf
		echo "--- CUT HERE ---"
		echo
	fi
fi
echo "Installation complete. Don't forget to setup iptables properly."
